@@ -224,6 +224,7 @@
 #define __NR_tgkill	268
 #define __NR_utimes	269
 #define __NR_fadvise64_64	270
+#define __NR_arm_fadvise64_64	270
 #define __NR_pciconfig_iobase	271
 #define __NR_pciconfig_read	272
 #define __NR_pciconfig_write	273
@@ -295,6 +296,7 @@
 #define __NR_get_robust_list	339
 #define __NR_splice	340
 #define __NR_sync_file_range2	341
+#define __NR_arm_sync_file_range	341
 #define __NR_tee	342
 #define __NR_vmsplice	343
 #define __NR_move_pages	344
@@ -583,6 +585,7 @@
 #define SYS_tgkill	268
 #define SYS_utimes	269
 #define SYS_fadvise64_64	270
+#define SYS_arm_fadvise64_64	270
 #define SYS_pciconfig_iobase	271
 #define SYS_pciconfig_read	272
 #define SYS_pciconfig_write	273
@@ -654,6 +657,7 @@
 #define SYS_get_robust_list	339
 #define SYS_splice	340
 #define SYS_sync_file_range2	341
+#define SYS_arm_sync_file_range	341
 #define SYS_tee	342
 #define SYS_vmsplice	343
 #define SYS_move_pages	344
